import { highlightText } from './core';
import { h } from 'vue';

// 通用的组件选项
const commonOptions = {
  name: 'UniversalHighlighter',
  props: {
    text: {
      type: String,
      required: true
    },
    searchWords: {
      type: [String, Array],
      required: true
    },
    caseSensitive: {
      type: Boolean,
      default: false
    },
    highlightStyle: {
      type: String,
      default: 'background-color: yellow; font-weight: bold;'
    }
  }
};

// Vue 2 版本
const Vue2Component = {
  ...commonOptions,
  computed: {
    highlightedText() {
      return highlightText(this.text, this.searchWords, this.caseSensitive, this.highlightStyle);
    }
  },
  render(h) {
    return h('span', {
      domProps: {
        innerHTML: this.highlightedText
      }
    });
  }
};

// Vue 3 版本
const Vue3Component = {
  ...commonOptions,
  setup(props) {
    const highlightedText = () => {
      return highlightText(props.text, props.searchWords, props.caseSensitive, props.highlightStyle);
    };

    return () => {
      return h('span', { innerHTML: highlightedText() });
    };
  }
};

// 导出一个工厂函数，根据 Vue 版本返回相应的组件
export default function createUniversalHighlighter(Vue) {
  if (Vue.version.startsWith('2.')) {
    return Vue2Component;
  } else {
    return Vue3Component;
  }
}